Struct ExtWorkspaceGroupHandleV1
pub struct ExtWorkspaceGroupHandleV1 { /* private fields */ }wayland and Linux only.Expand description
a workspace group assigned to a set of outputs
A ext_workspace_group_handle_v1 object represents a workspace group that is assigned a set of outputs and contains a number of workspaces.
The set of outputs assigned to the workspace group is conveyed to the client via output_enter and output_leave events, and its workspaces are conveyed with workspace events.
For example, a compositor which has a set of workspaces for each output may advertise a workspace group (and its workspaces) per output, whereas a compositor where a workspace spans all outputs may advertise a single workspace group for all outputs.
See also the Request enum for this interface.
Implementations
impl ExtWorkspaceGroupHandleV1
impl ExtWorkspaceGroupHandleV1
pub fn capabilities(&self, capabilities: GroupCapabilities)
pub fn capabilities(&self, capabilities: GroupCapabilities)
compositor capabilities
This event advertises the capabilities supported by the compositor. If a capability isn’t supported, clients should hide or disable the UI elements that expose this functionality. For instance, if the compositor doesn’t advertise support for creating workspaces, a button triggering the create_workspace request should not be displayed.
The compositor will ignore requests it doesn’t support. For instance, a compositor which doesn’t advertise support for creating workspaces will ignore create_workspace requests.
Compositors must send this event once after creation of an ext_workspace_group_handle_v1. When the capabilities change, compositors must send this event again.
pub fn output_enter(&self, output: &WlOutput)
pub fn output_enter(&self, output: &WlOutput)
output assigned to workspace group
This event is emitted whenever an output is assigned to the workspace
group or a new wl_output object is bound by the client, which was already
assigned to this workspace_group.
pub fn output_leave(&self, output: &WlOutput)
pub fn output_leave(&self, output: &WlOutput)
output removed from workspace group
This event is emitted whenever an output is removed from the workspace group.
pub fn workspace_enter(&self, workspace: &ExtWorkspaceHandleV1)
pub fn workspace_enter(&self, workspace: &ExtWorkspaceHandleV1)
workspace added to workspace group
This event is emitted whenever a workspace is assigned to this group. A workspace may only ever be assigned to a single group at a single point in time, but can be re-assigned during it’s lifetime.
pub fn workspace_leave(&self, workspace: &ExtWorkspaceHandleV1)
pub fn workspace_leave(&self, workspace: &ExtWorkspaceHandleV1)
workspace removed from workspace group
This event is emitted whenever a workspace is removed from this group.
pub fn removed(&self)
pub fn removed(&self)
this workspace group has been removed
This event is send when the group associated with the ext_workspace_group_handle_v1 has been removed. After sending this request the compositor will immediately consider the object inert. Any requests will be ignored except the destroy request. It is guaranteed there won’t be any more events referencing this ext_workspace_group_handle_v1.
The compositor must remove all workspaces belonging to a workspace group via a workspace_leave event before removing the workspace group.